Dir

Struct Dir 

pub struct Dir(/* private fields */);
An open directory.

This is a lower-level interface than std::fs::ReadDir. Notable differences:

  • can be opened from a file descriptor (as returned by openat, perhaps before knowing if the path represents a file or directory).
  • implements AsFd, so it can be passed to fstat, openat, etc. The file descriptor continues to be owned by the Dir, so callers must not keep a RawFd after the Dir is dropped.
  • can be iterated through multiple times without closing and reopening the file descriptor. Each iteration rewinds when finished.
  • returns entries for . (current directory) and .. (parent directory).
  • returns entries’ names as a CStr (no allocation or conversion beyond whatever libc does).

Examples

Traverse the current directory, and print entries’ names:

use nix::dir::Dir;
use nix::fcntl::OFlag;
use nix::sys::stat::Mode;

let mut cwd = Dir::open(".", OFlag::O_RDONLY | OFlag::O_CLOEXEC, Mode::empty()).unwrap();
for res_entry in cwd.iter() {
    let entry = res_entry.unwrap();
    println!("File name: {}", entry.file_name().to_string_lossy());
}

Implementations

Source

impl Dir

pub fn open<P: ?Sized + NixPath>( path: &P, oflag: OFlag, mode: Mode, ) -> Result<Self>

Opens the given path as with fcntl::open.

pub fn openat<Fd: AsFd, P: ?Sized + NixPath>( dirfd: Fd, path: &P, oflag: OFlag, mode: Mode, ) -> Result<Self>

Opens the given path as with fcntl::openat.

pub unsafe fn from<F: IntoRawFd>(fd: F) -> Result<Self>

👎Deprecated since 0.30.0:

Deprecate this since it is not I/O-safe, use from_fd instead.

Converts from a descriptor-based object, closing the descriptor on success or failure.

Safety

It is only safe if fd is an owned file descriptor.

pub fn from_fd(fd: OwnedFd) -> Result<Self>

Converts from a file descriptor, closing it on failure.

Examples

ENOTDIR would be returned if fd does not refer to a directory:

use std::os::fd::OwnedFd;
use nix::dir::Dir;

let temp_file = tempfile::tempfile().unwrap();
let temp_file_fd: OwnedFd = temp_file.into();
let never = Dir::from_fd(temp_file_fd).unwrap();
pub fn iter(&mut self) -> Iter<'_>

Returns an iterator of Result<Entry> which rewinds when finished.