Function fallocate

fn fallocate<Fd: std::os::fd::AsFd>(fd: Fd, mode: FallocateFlags, offset: off_t, len: off_t) -> Result<()>

Manipulates file space.

Allows the caller to directly manipulate the allocated disk space for the file referred to by fd.