Function posix_fadvise

fn posix_fadvise<Fd: std::os::fd::AsFd>(fd: Fd, offset: off_t, len: off_t, advice: PosixFadviseAdvice) -> Result<()>

Allows a process to describe to the system its data access behavior for an open file descriptor.

See Also