Struct AtFlags

struct AtFlags(_)

Flags that control how the various *at syscalls behave.

Implementations

impl AtFlags

const fn iter(self: &Self) -> Iter<AtFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

const fn iter_names(self: &Self) -> IterNames<AtFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

impl AtFlags

impl AtFlags

const fn empty() -> Self

Get a flags value with all bits unset.

const fn all() -> Self

Get a flags value with all known bits set.

const fn bits(self: &Self) -> c_int

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

const fn from_bits(bits: c_int) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

const fn from_bits_truncate(bits: c_int) -> Self

Convert from a bits value, unsetting any unknown bits.

const fn from_bits_retain(bits: c_int) -> Self

Convert from a bits value exactly.

fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn't correspond to any named flag.

const fn is_empty(self: &Self) -> bool

Whether all bits in this flags value are unset.

const fn is_all(self: &Self) -> bool

Whether all known bits in this flags value are set.

const fn intersects(self: &Self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

const fn contains(self: &Self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

fn insert(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

fn remove(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won't truncate other, but the ! operator will.

fn toggle(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

fn set(self: &mut Self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

const fn intersection(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

const fn union(self: Self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

const fn difference(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

const fn symmetric_difference(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

const fn complement(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl AtFlags

impl Binary for AtFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl BitAnd for AtFlags

fn bitand(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

impl BitAndAssign for AtFlags

fn bitand_assign(self: &mut Self, other: Self)

The bitwise and (&) of the bits in two flags values.

impl BitOr for AtFlags

fn bitor(self: Self, other: AtFlags) -> Self

The bitwise or (|) of the bits in two flags values.

impl BitOrAssign for AtFlags

fn bitor_assign(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

impl BitXor for AtFlags

fn bitxor(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

impl BitXorAssign for AtFlags

fn bitxor_assign(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

impl Clone for AtFlags

fn clone(self: &Self) -> AtFlags

impl Copy for AtFlags

impl Debug for AtFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for AtFlags

impl Extend for AtFlags

fn extend<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(self: &mut Self, iterator: T)

The bitwise or (|) of the bits in each flags value.

impl Flags for AtFlags

fn bits(self: &Self) -> c_int
fn from_bits_retain(bits: c_int) -> AtFlags

impl Freeze for AtFlags

impl FromIterator for AtFlags

fn from_iter<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(iterator: T) -> Self

The bitwise or (|) of the bits in each flags value.

impl Hash for AtFlags

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl IntoIterator for AtFlags

fn into_iter(self: Self) -> <Self as >::IntoIter

impl LowerHex for AtFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Not for AtFlags

fn not(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl Octal for AtFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Ord for AtFlags

fn cmp(self: &Self, other: &AtFlags) -> Ordering

impl PartialEq for AtFlags

fn eq(self: &Self, other: &AtFlags) -> bool

impl PartialOrd for AtFlags

fn partial_cmp(self: &Self, other: &AtFlags) -> Option<Ordering>

impl PublicFlags for AtFlags

impl RefUnwindSafe for AtFlags

impl Send for AtFlags

impl StructuralPartialEq for AtFlags

impl Sub for AtFlags

fn sub(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl SubAssign for AtFlags

fn sub_assign(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl Sync for AtFlags

impl Unpin for AtFlags

impl UnsafeUnpin for AtFlags

impl UnwindSafe for AtFlags

impl UpperHex for AtFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for AtFlags

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for AtFlags

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for AtFlags

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for AtFlags

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for AtFlags

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for AtFlags

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for AtFlags

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for AtFlags

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for AtFlags

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>