macro_rules! request_code_write_int {
($g:expr, $n:expr) => { ... };
}Available on Unix only.
Generate an ioctl request code for a command that passes an integer
This is equivalent to the _IOWINT() macro exposed by the C ioctl API.
You should only use this macro directly if the ioctl you’re working
with is “bad” and you cannot use ioctl_write_int!() directly.