Struct PtyMaster
struct PtyMaster(_)
Representation of the Master device in a master/slave pty pair
While this datatype is a thin wrapper around OwnedFd, it enforces that the available PTY
functions are given the correct file descriptor.
Implementations
impl PtyMaster
unsafe fn from_owned_fd(fd: OwnedFd) -> SelfConstructs a
PytMasterwrapping an existingOwnedFd.Safety
OwnedFdis a validPtyMaster.
impl AsFd for PtyMaster
fn as_fd(self: &Self) -> BorrowedFd<'_>
impl AsRawFd for PtyMaster
fn as_raw_fd(self: &Self) -> RawFd
impl Debug for PtyMaster
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for PtyMaster
impl IntoRawFd for PtyMaster
fn into_raw_fd(self: Self) -> RawFd
impl Read for PtyMaster
fn read(self: &mut Self, buf: &mut [u8]) -> Result<usize>
impl RefUnwindSafe for PtyMaster
impl Send for PtyMaster
impl Sync for PtyMaster
impl Unpin for PtyMaster
impl UnsafeUnpin for PtyMaster
impl UnwindSafe for PtyMaster
impl Write for PtyMaster
fn write(self: &mut Self, buf: &[u8]) -> Result<usize>fn flush(self: &mut Self) -> Result<()>
impl<T> Any for PtyMaster
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PtyMaster
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PtyMaster
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for PtyMaster
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for PtyMaster
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PtyMaster
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PtyMaster
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>