Struct PosixSpawnFlags

struct PosixSpawnFlags(_)

Process attributes to be changed in the new process image when invoking posix_spawn or posix_spawnp. See posix_spawn.

Implementations

impl PosixSpawnFlags

impl PosixSpawnFlags

const fn empty() -> Self

Get a flags value with all bits unset.

const fn all() -> Self

Get a flags value with all known bits set.

const fn bits(self: &Self) -> c_int

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

const fn from_bits(bits: c_int) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

const fn from_bits_truncate(bits: c_int) -> Self

Convert from a bits value, unsetting any unknown bits.

const fn from_bits_retain(bits: c_int) -> Self

Convert from a bits value exactly.

fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn't correspond to any named flag.

const fn is_empty(self: &Self) -> bool

Whether all bits in this flags value are unset.

const fn is_all(self: &Self) -> bool

Whether all known bits in this flags value are set.

const fn intersects(self: &Self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

const fn contains(self: &Self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

fn insert(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

fn remove(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won't truncate other, but the ! operator will.

fn toggle(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

fn set(self: &mut Self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

const fn intersection(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

const fn union(self: Self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

const fn difference(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

const fn symmetric_difference(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

const fn complement(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl PosixSpawnFlags

const fn iter(self: &Self) -> Iter<PosixSpawnFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

const fn iter_names(self: &Self) -> IterNames<PosixSpawnFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

impl Binary for PosixSpawnFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl BitAnd for PosixSpawnFlags

fn bitand(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

impl BitAndAssign for PosixSpawnFlags

fn bitand_assign(self: &mut Self, other: Self)

The bitwise and (&) of the bits in two flags values.

impl BitOr for PosixSpawnFlags

fn bitor(self: Self, other: PosixSpawnFlags) -> Self

The bitwise or (|) of the bits in two flags values.

impl BitOrAssign for PosixSpawnFlags

fn bitor_assign(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

impl BitXor for PosixSpawnFlags

fn bitxor(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

impl BitXorAssign for PosixSpawnFlags

fn bitxor_assign(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

impl Clone for PosixSpawnFlags

fn clone(self: &Self) -> PosixSpawnFlags

impl Copy for PosixSpawnFlags

impl Debug for PosixSpawnFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for PosixSpawnFlags

impl Extend for PosixSpawnFlags

fn extend<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(self: &mut Self, iterator: T)

The bitwise or (|) of the bits in each flags value.

impl Flags for PosixSpawnFlags

fn bits(self: &Self) -> c_int
fn from_bits_retain(bits: c_int) -> PosixSpawnFlags

impl Freeze for PosixSpawnFlags

impl FromIterator for PosixSpawnFlags

fn from_iter<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(iterator: T) -> Self

The bitwise or (|) of the bits in each flags value.

impl Hash for PosixSpawnFlags

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl IntoIterator for PosixSpawnFlags

fn into_iter(self: Self) -> <Self as >::IntoIter

impl LowerHex for PosixSpawnFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Not for PosixSpawnFlags

fn not(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl Octal for PosixSpawnFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Ord for PosixSpawnFlags

fn cmp(self: &Self, other: &PosixSpawnFlags) -> Ordering

impl PartialEq for PosixSpawnFlags

fn eq(self: &Self, other: &PosixSpawnFlags) -> bool

impl PartialOrd for PosixSpawnFlags

fn partial_cmp(self: &Self, other: &PosixSpawnFlags) -> Option<Ordering>

impl PublicFlags for PosixSpawnFlags

impl RefUnwindSafe for PosixSpawnFlags

impl Send for PosixSpawnFlags

impl StructuralPartialEq for PosixSpawnFlags

impl Sub for PosixSpawnFlags

fn sub(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl SubAssign for PosixSpawnFlags

fn sub_assign(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl Sync for PosixSpawnFlags

impl Unpin for PosixSpawnFlags

impl UnsafeUnpin for PosixSpawnFlags

impl UnwindSafe for PosixSpawnFlags

impl UpperHex for PosixSpawnFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for PosixSpawnFlags

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PosixSpawnFlags

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PosixSpawnFlags

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for PosixSpawnFlags

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for PosixSpawnFlags

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for PosixSpawnFlags

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for PosixSpawnFlags

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PosixSpawnFlags

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PosixSpawnFlags

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>