Struct MFdFlags

struct MFdFlags(_)

Options that change the behavior of memfd_create.

Implementations

impl MFdFlags

impl MFdFlags

const fn empty() -> Self

Get a flags value with all bits unset.

const fn all() -> Self

Get a flags value with all known bits set.

const fn bits(self: &Self) -> c_uint

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

const fn from_bits(bits: c_uint) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

const fn from_bits_truncate(bits: c_uint) -> Self

Convert from a bits value, unsetting any unknown bits.

const fn from_bits_retain(bits: c_uint) -> Self

Convert from a bits value exactly.

fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn't correspond to any named flag.

const fn is_empty(self: &Self) -> bool

Whether all bits in this flags value are unset.

const fn is_all(self: &Self) -> bool

Whether all known bits in this flags value are set.

const fn intersects(self: &Self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

const fn contains(self: &Self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

fn insert(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

fn remove(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won't truncate other, but the ! operator will.

fn toggle(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

fn set(self: &mut Self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

const fn intersection(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

const fn union(self: Self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

const fn difference(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

const fn symmetric_difference(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

const fn complement(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl MFdFlags

const fn iter(self: &Self) -> Iter<MFdFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

const fn iter_names(self: &Self) -> IterNames<MFdFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

impl Binary for MFdFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl BitAnd for MFdFlags

fn bitand(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

impl BitAndAssign for MFdFlags

fn bitand_assign(self: &mut Self, other: Self)

The bitwise and (&) of the bits in two flags values.

impl BitOr for MFdFlags

fn bitor(self: Self, other: MFdFlags) -> Self

The bitwise or (|) of the bits in two flags values.

impl BitOrAssign for MFdFlags

fn bitor_assign(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

impl BitXor for MFdFlags

fn bitxor(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

impl BitXorAssign for MFdFlags

fn bitxor_assign(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

impl Clone for MFdFlags

fn clone(self: &Self) -> MFdFlags

impl Copy for MFdFlags

impl Debug for MFdFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for MFdFlags

impl Extend for MFdFlags

fn extend<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(self: &mut Self, iterator: T)

The bitwise or (|) of the bits in each flags value.

impl Flags for MFdFlags

fn bits(self: &Self) -> c_uint
fn from_bits_retain(bits: c_uint) -> MFdFlags

impl Freeze for MFdFlags

impl FromIterator for MFdFlags

fn from_iter<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(iterator: T) -> Self

The bitwise or (|) of the bits in each flags value.

impl Hash for MFdFlags

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl IntoIterator for MFdFlags

fn into_iter(self: Self) -> <Self as >::IntoIter

impl LowerHex for MFdFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Not for MFdFlags

fn not(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl Octal for MFdFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Ord for MFdFlags

fn cmp(self: &Self, other: &MFdFlags) -> Ordering

impl PartialEq for MFdFlags

fn eq(self: &Self, other: &MFdFlags) -> bool

impl PartialOrd for MFdFlags

fn partial_cmp(self: &Self, other: &MFdFlags) -> Option<Ordering>

impl PublicFlags for MFdFlags

impl RefUnwindSafe for MFdFlags

impl Send for MFdFlags

impl StructuralPartialEq for MFdFlags

impl Sub for MFdFlags

fn sub(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl SubAssign for MFdFlags

fn sub_assign(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl Sync for MFdFlags

impl Unpin for MFdFlags

impl UnsafeUnpin for MFdFlags

impl UnwindSafe for MFdFlags

impl UpperHex for MFdFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for MFdFlags

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MFdFlags

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MFdFlags

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for MFdFlags

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for MFdFlags

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for MFdFlags

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for MFdFlags

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MFdFlags

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MFdFlags

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>