pub struct MapFlags(/* private fields */);Expand description
Additional parameters for mmap.
Implementations
Sourceimpl MapFlags
impl MapFlags
Sourcepub const MAP_SHARED: Self
pub const MAP_SHARED: Self
Share this mapping. Mutually exclusive with MAP_PRIVATE.
Sourcepub const MAP_PRIVATE: Self
pub const MAP_PRIVATE: Self
Create a private copy-on-write mapping. Mutually exclusive with MAP_SHARED.
Sourcepub const MAP_FIXED_NOREPLACE: Self
pub const MAP_FIXED_NOREPLACE: Self
Place the mapping at exactly the address specified in addr, but never clobber an existing range.
Sourcepub const MAP_ANONYMOUS: Self
pub const MAP_ANONYMOUS: Self
The mapping is not backed by any file.
Sourcepub const MAP_GROWSDOWN: Self
pub const MAP_GROWSDOWN: Self
Used for stacks; indicates to the kernel that the mapping should extend downward in memory.
Sourcepub const MAP_DENYWRITE: Self
pub const MAP_DENYWRITE: Self
Compatibility flag. Ignored.
Sourcepub const MAP_EXECUTABLE: Self
pub const MAP_EXECUTABLE: Self
Compatibility flag. Ignored.
Sourcepub const MAP_LOCKED: Self
pub const MAP_LOCKED: Self
Mark the mmaped region to be locked in the same way as mlock(2).
Sourcepub const MAP_NORESERVE: Self
pub const MAP_NORESERVE: Self
Do not reserve swap space for this mapping.
This was removed in FreeBSD 11 and is unused in DragonFlyBSD.
Sourcepub const MAP_POPULATE: Self
pub const MAP_POPULATE: Self
Populate page tables for a mapping.
Sourcepub const MAP_NONBLOCK: Self
pub const MAP_NONBLOCK: Self
Only meaningful when used with MAP_POPULATE. Don’t perform read-ahead.
Sourcepub const MAP_HUGETLB: Self
pub const MAP_HUGETLB: Self
Allocate the mapping using “huge pages.”
Sourcepub const MAP_HUGE_64KB: Self
pub const MAP_HUGE_64KB: Self
Make use of 64KB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_512KB: Self
pub const MAP_HUGE_512KB: Self
Make use of 512KB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_1MB: Self
pub const MAP_HUGE_1MB: Self
Make use of 1MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_2MB: Self
pub const MAP_HUGE_2MB: Self
Make use of 2MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_8MB: Self
pub const MAP_HUGE_8MB: Self
Make use of 8MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_16MB: Self
pub const MAP_HUGE_16MB: Self
Make use of 16MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_32MB: Self
pub const MAP_HUGE_32MB: Self
Make use of 32MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_256MB: Self
pub const MAP_HUGE_256MB: Self
Make use of 256MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_512MB: Self
pub const MAP_HUGE_512MB: Self
Make use of 512MB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_1GB: Self
pub const MAP_HUGE_1GB: Self
Make use of 1GB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_2GB: Self
pub const MAP_HUGE_2GB: Self
Make use of 2GB huge page (must be supported by the system)
Sourcepub const MAP_HUGE_16GB: Self
pub const MAP_HUGE_16GB: Self
Make use of 16GB huge page (must be supported by the system)
Sourceimpl MapFlags
impl MapFlags
Sourcepub const fn bits(&self) -> c_int
pub const fn bits(&self) -> c_int
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: c_int) -> Option<Self>
pub const fn from_bits(bits: c_int) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: c_int) -> Self
pub const fn from_bits_truncate(bits: c_int) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: c_int) -> Self
pub const fn from_bits_retain(bits: c_int) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl MapFlags
impl MapFlags
Sourceimpl MapFlags
impl MapFlags
Sourcepub fn map_hugetlb_with_size_log2(huge_page_size_log2: u32) -> Option<Self>
pub fn map_hugetlb_with_size_log2(huge_page_size_log2: u32) -> Option<Self>
Create MAP_HUGETLB with provided size of huge page.
Under the hood it computes MAP_HUGETLB | (huge_page_size_log2 << libc::MAP_HUGE_SHIFT).
huge_page_size_log2 denotes logarithm of huge page size to use and should be
between 16 and 63 (inclusively).
let f = MapFlags::map_hugetlb_with_size_log2(30).unwrap();
assert_eq!(f, MapFlags::MAP_HUGETLB | MapFlags::MAP_HUGE_1GB);Trait Implementations
Sourceimpl BitAndAssign for MapFlags
impl BitAndAssign for MapFlags
Sourcefn bitand_assign(&mut self, other: Self)
fn bitand_assign(&mut self, other: Self)
The bitwise and (&) of the bits in self and other.
Sourceimpl BitOrAssign for MapFlags
impl BitOrAssign for MapFlags
Sourcefn bitor_assign(&mut self, other: Self)
fn bitor_assign(&mut self, other: Self)
The bitwise or (|) of the bits in self and other.
Sourceimpl BitXorAssign for MapFlags
impl BitXorAssign for MapFlags
Sourcefn bitxor_assign(&mut self, other: Self)
fn bitxor_assign(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
impl Copy for MapFlags
impl Eq for MapFlags
Sourceimpl Extend<MapFlags> for MapFlags
impl Extend<MapFlags> for MapFlags
Sourcefn extend<T: IntoIterator<Item = Self>>(&mut self, iterator: T)
fn extend<T: IntoIterator<Item = Self>>(&mut self, iterator: T)
The bitwise or (|) of the bits in each flags value.
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)Sourceimpl Flags for MapFlags
impl Flags for MapFlags
Sourcefn from_bits_retain(bits: c_int) -> MapFlags
fn from_bits_retain(bits: c_int) -> MapFlags
Sourcefn known_bits(&self) -> Self::Bits
fn known_bits(&self) -> Self::Bits
Sourcefn unknown_bits(&self) -> Self::Bits
fn unknown_bits(&self) -> Self::Bits
Sourcefn contains_unknown_bits(&self) -> bool
fn contains_unknown_bits(&self) -> bool
true if any unknown bits are set.Sourcefn from_bits_truncate(bits: Self::Bits) -> Self
fn from_bits_truncate(bits: Self::Bits) -> Self
Sourcefn from_name(name: &str) -> Option<Self>
fn from_name(name: &str) -> Option<Self>
Sourcefn iter_names(&self) -> IterNames<Self> ⓘ
fn iter_names(&self) -> IterNames<Self> ⓘ
Sourcefn iter_defined_names() -> IterDefinedNames<Self> ⓘ
fn iter_defined_names() -> IterDefinedNames<Self> ⓘ
Self::FLAGS.Sourcefn iter_equal_names(&self) -> IterEqualNames<Self> ⓘ
fn iter_equal_names(&self) -> IterEqualNames<Self> ⓘ
Sourcefn intersects(&self, other: Self) -> boolwhere
Self: Sized,
fn intersects(&self, other: Self) -> boolwhere
Self: Sized,
other are also set in self.Sourcefn contains(&self, other: Self) -> boolwhere
Self: Sized,
fn contains(&self, other: Self) -> boolwhere
Self: Sized,
other are also set in self.Sourcefn insert(&mut self, other: Self)where
Self: Sized,
fn insert(&mut self, other: Self)where
Self: Sized,
|) of the bits in self and other.Sourcefn toggle(&mut self, other: Self)where
Self: Sized,
fn toggle(&mut self, other: Self)where
Self: Sized,
^) of the bits in self and other.Sourcefn intersection(self, other: Self) -> Self
fn intersection(self, other: Self) -> Self
&) of the bits in self and other.Sourcefn difference(self, other: Self) -> Self
fn difference(self, other: Self) -> Self
Sourcefn symmetric_difference(self, other: Self) -> Self
fn symmetric_difference(self, other: Self) -> Self
^) of the bits in self and other.Sourcefn complement(self) -> Self
fn complement(self) -> Self
!) of the bits in self, truncating the result.Sourceimpl FromIterator<MapFlags> for MapFlags
impl FromIterator<MapFlags> for MapFlags
Sourcefn from_iter<T: IntoIterator<Item = Self>>(iterator: T) -> Self
fn from_iter<T: IntoIterator<Item = Self>>(iterator: T) -> Self
The bitwise or (|) of the bits in each flags value.