pub struct Persona(/* private fields */);Implementations
Sourceimpl Persona
impl Persona
Sourcepub const ADDR_COMPAT_LAYOUT: Self
pub const ADDR_COMPAT_LAYOUT: Self
Provide the legacy virtual address space layout.
Sourcepub const ADDR_NO_RANDOMIZE: Self
pub const ADDR_NO_RANDOMIZE: Self
Disable address-space-layout randomization.
Sourcepub const ADDR_LIMIT_32BIT: Self
pub const ADDR_LIMIT_32BIT: Self
Limit the address space to 32 bits.
Sourcepub const ADDR_LIMIT_3GB: Self
pub const ADDR_LIMIT_3GB: Self
Use 0xc0000000 as the offset at which to search a virtual memory
chunk on mmap(2), otherwise use 0xffffe000.
Sourcepub const FDPIC_FUNCPTRS: Self
pub const FDPIC_FUNCPTRS: Self
User-space function pointers to signal handlers point to descriptors.
Sourcepub const MMAP_PAGE_ZERO: Self
pub const MMAP_PAGE_ZERO: Self
Map page 0 as read-only.
Sourcepub const READ_IMPLIES_EXEC: Self
pub const READ_IMPLIES_EXEC: Self
PROT_READ implies PROT_EXEC for mmap(2).
Sourcepub const SHORT_INODE: Self
pub const SHORT_INODE: Self
No effects.
Sourcepub const STICKY_TIMEOUTS: Self
pub const STICKY_TIMEOUTS: Self
select(2), pselect(2), and ppoll(2) do not modify the
returned timeout argument when interrupted by a signal handler.
Sourcepub const UNAME26: Self
pub const UNAME26: Self
Have uname(2) report a 2.6.40+ version number rather than a 3.x
version number.
Sourcepub const WHOLE_SECONDS: Self
pub const WHOLE_SECONDS: Self
No effects.
Sourceimpl Persona
impl Persona
Sourcepub const fn bits(&self) -> c_int
pub const fn bits(&self) -> c_int
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: c_int) -> Option<Self>
pub const fn from_bits(bits: c_int) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: c_int) -> Self
pub const fn from_bits_truncate(bits: c_int) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: c_int) -> Self
pub const fn from_bits_retain(bits: c_int) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Persona
impl Persona
Sourcepub const fn iter(&self) -> Iter<Persona>
pub const fn iter(&self) -> Iter<Persona>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Persona>
pub const fn iter_names(&self) -> IterNames<Persona>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.