Enum PrctlMCEKillPolicy

enum PrctlMCEKillPolicy

The type of hardware memory corruption kill policy for the thread.

Variants

PR_MCE_KILL_EARLY

The thread will receive SIGBUS as soon as a memory corruption is detected.

PR_MCE_KILL_LATE

The process is killed only when it accesses a corrupted page.

PR_MCE_KILL_DEFAULT

Uses the system-wide default.

Implementations

impl Clone for PrctlMCEKillPolicy

fn clone(self: &Self) -> PrctlMCEKillPolicy

impl Copy for PrctlMCEKillPolicy

impl Debug for PrctlMCEKillPolicy

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for PrctlMCEKillPolicy

impl Freeze for PrctlMCEKillPolicy

impl Hash for PrctlMCEKillPolicy

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for PrctlMCEKillPolicy

fn cmp(self: &Self, other: &PrctlMCEKillPolicy) -> Ordering

impl PartialEq for PrctlMCEKillPolicy

fn eq(self: &Self, other: &PrctlMCEKillPolicy) -> bool

impl PartialOrd for PrctlMCEKillPolicy

fn partial_cmp(self: &Self, other: &PrctlMCEKillPolicy) -> Option<Ordering>

impl RefUnwindSafe for PrctlMCEKillPolicy

impl Send for PrctlMCEKillPolicy

impl StructuralPartialEq for PrctlMCEKillPolicy

impl Sync for PrctlMCEKillPolicy

impl TryFrom for PrctlMCEKillPolicy

fn try_from(x: i32) -> Result<Self>

impl Unpin for PrctlMCEKillPolicy

impl UnsafeUnpin for PrctlMCEKillPolicy

impl UnwindSafe for PrctlMCEKillPolicy

impl<T> Any for PrctlMCEKillPolicy

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PrctlMCEKillPolicy

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PrctlMCEKillPolicy

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for PrctlMCEKillPolicy

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for PrctlMCEKillPolicy

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for PrctlMCEKillPolicy

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for PrctlMCEKillPolicy

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PrctlMCEKillPolicy

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PrctlMCEKillPolicy

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>