Function clear_mce_kill
fn clear_mce_kill() -> Result<()>
Clear the thread memory corruption kill policy and use the system-wide default
clear_mce_killfn clear_mce_kill() -> Result<()>
Clear the thread memory corruption kill policy and use the system-wide default