Function set_dumpable
fn set_dumpable(attribute: bool) -> Result<()>
Set the dumpable attribute which determines if core dumps are created for this process.
set_dumpablefn set_dumpable(attribute: bool) -> Result<()>
Set the dumpable attribute which determines if core dumps are created for this process.