Function set_timerslack

fn set_timerslack(ns: c_ulong) -> Result<()>

Sets the timer slack value for the calling thread. Timer slack is used by the kernel to group timer expirations and make them the supplied amount of nanoseconds late.