Function task_perf_events_disable
fn task_perf_events_disable() -> Result<()>
Disable all performance counters attached to the calling process.
task_perf_events_disablefn task_perf_events_disable() -> Result<()>
Disable all performance counters attached to the calling process.