Function task_perf_events_enable
fn task_perf_events_enable() -> Result<()>
Enable all performance counters attached to the calling process.
task_perf_events_enablefn task_perf_events_enable() -> Result<()>
Enable all performance counters attached to the calling process.