#[repr(u32)]
#[non_exhaustive]
pub enum Resource {
Show 16 variants
RLIMIT_AS,
RLIMIT_CORE,
RLIMIT_CPU,
RLIMIT_DATA,
RLIMIT_FSIZE,
RLIMIT_NOFILE,
RLIMIT_STACK,
RLIMIT_LOCKS,
RLIMIT_MEMLOCK,
RLIMIT_MSGQUEUE,
RLIMIT_NICE,
RLIMIT_NPROC,
RLIMIT_RSS,
RLIMIT_RTPRIO,
RLIMIT_RTTIME,
RLIMIT_SIGPENDING,
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
RLIMIT_AS
The maximum amount (in bytes) of virtual memory the process is allowed to map.
RLIMIT_CORE
The largest size (in bytes) core(5) file that may be created.
RLIMIT_CPU
The maximum amount of cpu time (in seconds) to be used by each process.
RLIMIT_DATA
The maximum size (in bytes) of the data segment for a process
RLIMIT_FSIZE
The largest size (in bytes) file that may be created.
RLIMIT_NOFILE
The maximum number of open files for this process.
RLIMIT_STACK
The maximum size (in bytes) of the stack segment for a process.
RLIMIT_LOCKS
A limit on the combined number of flock locks and fcntl leases that this process may establish.
RLIMIT_MEMLOCK
The maximum size (in bytes) which a process may lock into memory using the mlock(2) system call.
RLIMIT_MSGQUEUE
A limit on the number of bytes that can be allocated for POSIX message queues for the real user ID of the calling process.
RLIMIT_NICE
A ceiling to which the process’s nice value can be raised using setpriority or nice.
RLIMIT_NPROC
The maximum number of simultaneous processes for this user id.
RLIMIT_RSS
When there is memory pressure and swap is available, prioritize eviction of a process’ resident pages beyond this amount (in bytes).
RLIMIT_RTPRIO
A ceiling on the real-time priority that may be set for this process using sched_setscheduler and sched_set‐ param.
RLIMIT_RTTIME
A limit (in microseconds) on the amount of CPU time that a process scheduled under a real-time scheduling policy may con‐ sume without making a blocking system call.
RLIMIT_SIGPENDING
A limit on the number of signals that may be queued for the real user ID of the calling process.