Struct FdSet

struct FdSet<'fd> { ... }

Contains a set of file descriptors used by select

Implementations

impl<'fd> FdSet<'fd>

fn new() -> FdSet<'fd>

Create an empty FdSet

fn insert(self: &mut Self, fd: BorrowedFd<'fd>)

Add a file descriptor to an FdSet

fn remove(self: &mut Self, fd: BorrowedFd<'fd>)

Remove a file descriptor from an FdSet

fn contains(self: &Self, fd: BorrowedFd<'fd>) -> bool

Test an FdSet for the presence of a certain file descriptor.

fn clear(self: &mut Self)

Remove all file descriptors from this FdSet.

fn highest(self: &Self) -> Option<BorrowedFd<'_>>

Finds the highest file descriptor in the set.

Returns None if the set is empty.

This can be used to calculate the nfds parameter of the select function.

Example

# use std::os::unix::io::{AsRawFd, BorrowedFd};
# use nix::sys::select::FdSet;
let fd_four = unsafe {BorrowedFd::borrow_raw(4)};
let fd_nine = unsafe {BorrowedFd::borrow_raw(9)};
let mut set = FdSet::new();
set.insert(fd_four);
set.insert(fd_nine);
assert_eq!(set.highest().map(|borrowed_fd|borrowed_fd.as_raw_fd()), Some(9));
fn fds(self: &Self, highest: Option<RawFd>) -> Fds<'_, '_>

Returns an iterator over the file descriptors in the set.

For performance, it takes an optional higher bound: the iterator will not return any elements of the set greater than the given file descriptor.

Examples

# use nix::sys::select::FdSet;
# use std::os::unix::io::{AsRawFd, BorrowedFd, RawFd};
let mut set = FdSet::new();
let fd_four = unsafe {BorrowedFd::borrow_raw(4)};
let fd_nine = unsafe {BorrowedFd::borrow_raw(9)};
set.insert(fd_four);
set.insert(fd_nine);
let fds: Vec<RawFd> = set.fds(None).map(|borrowed_fd|borrowed_fd.as_raw_fd()).collect();
assert_eq!(fds, vec![4, 9]);

impl Default for FdSet<'_>

fn default() -> Self

impl<'fd> Clone for FdSet<'fd>

fn clone(self: &Self) -> FdSet<'fd>

impl<'fd> Copy for FdSet<'fd>

impl<'fd> Debug for FdSet<'fd>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'fd> Eq for FdSet<'fd>

impl<'fd> Freeze for FdSet<'fd>

impl<'fd> Hash for FdSet<'fd>

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl<'fd> PartialEq for FdSet<'fd>

fn eq(self: &Self, other: &FdSet<'fd>) -> bool

impl<'fd> RefUnwindSafe for FdSet<'fd>

impl<'fd> Send for FdSet<'fd>

impl<'fd> StructuralPartialEq for FdSet<'fd>

impl<'fd> Sync for FdSet<'fd>

impl<'fd> Unpin for FdSet<'fd>

impl<'fd> UnsafeUnpin for FdSet<'fd>

impl<'fd> UnwindSafe for FdSet<'fd>

impl<T> Any for FdSet<'fd>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FdSet<'fd>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FdSet<'fd>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FdSet<'fd>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FdSet<'fd>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for FdSet<'fd>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for FdSet<'fd>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FdSet<'fd>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FdSet<'fd>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>