Enum SigHandler

enum SigHandler

A signal handler.

Variants

SigDfl

Default signal handling.

SigIgn

Request that the signal be ignored.

Handler(extern C { unwind: false } fn(_: libc::c_int))

Use the given signal-catching function, which takes in the signal.

SigAction(extern C { unwind: false } fn(_: libc::c_int, _: *mut libc::siginfo_t, _: *mut libc::c_void))

Use the given signal-catching function, which takes in the signal, information about how the signal was generated, and a pointer to the threads ucontext_t.

Implementations

impl Clone for SigHandler

fn clone(self: &Self) -> SigHandler

impl Copy for SigHandler

impl Debug for SigHandler

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for SigHandler

impl Freeze for SigHandler

impl Hash for SigHandler

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for SigHandler

fn eq(self: &Self, other: &SigHandler) -> bool

impl RefUnwindSafe for SigHandler

impl Send for SigHandler

impl StructuralPartialEq for SigHandler

impl Sync for SigHandler

impl Unpin for SigHandler

impl UnsafeUnpin for SigHandler

impl UnwindSafe for SigHandler

impl<T> Any for SigHandler

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SigHandler

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SigHandler

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SigHandler

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SigHandler

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for SigHandler

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for SigHandler

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SigHandler

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SigHandler

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>