Enum SigmaskHow

enum SigmaskHow

Specifies how certain functions should manipulate a signal mask

Variants

SIG_BLOCK

The new mask is the union of the current mask and the specified set.

SIG_UNBLOCK

The new mask is the intersection of the current mask and the complement of the specified set.

SIG_SETMASK

The current mask is replaced by the specified set.

Implementations

impl Clone for SigmaskHow

fn clone(self: &Self) -> SigmaskHow

impl Copy for SigmaskHow

impl Debug for SigmaskHow

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for SigmaskHow

impl Freeze for SigmaskHow

impl Hash for SigmaskHow

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for SigmaskHow

fn cmp(self: &Self, other: &SigmaskHow) -> Ordering

impl PartialEq for SigmaskHow

fn eq(self: &Self, other: &SigmaskHow) -> bool

impl PartialOrd for SigmaskHow

fn partial_cmp(self: &Self, other: &SigmaskHow) -> Option<Ordering>

impl RefUnwindSafe for SigmaskHow

impl Send for SigmaskHow

impl StructuralPartialEq for SigmaskHow

impl Sync for SigmaskHow

impl Unpin for SigmaskHow

impl UnsafeUnpin for SigmaskHow

impl UnwindSafe for SigmaskHow

impl<T> Any for SigmaskHow

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SigmaskHow

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SigmaskHow

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SigmaskHow

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SigmaskHow

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for SigmaskHow

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for SigmaskHow

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SigmaskHow

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SigmaskHow

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>