Enum Signal

enum Signal

Types of operating system signals

Variants

SIGHUP

Hangup

SIGINT

Interrupt

SIGQUIT

Quit

SIGILL

Illegal instruction (not reset when caught)

SIGTRAP

Trace trap (not reset when caught)

SIGABRT

Abort

SIGBUS

Bus error

SIGFPE

Floating point exception

SIGKILL

Kill (cannot be caught or ignored)

SIGUSR1

User defined signal 1

SIGSEGV

Segmentation violation

SIGUSR2

User defined signal 2

SIGPIPE

Write on a pipe with no one to read it

SIGALRM

Alarm clock

SIGTERM

Software termination signal from kill

SIGSTKFLT

Stack fault (obsolete)

SIGCHLD

To parent on child stop or exit

SIGCONT

Continue a stopped process

SIGSTOP

Sendable stop signal not from tty

SIGTSTP

Stop signal from tty

SIGTTIN

To readers pgrp upon background tty read

SIGTTOU

Like TTIN if (tp->t_local&LTOSTOP)

SIGURG

Urgent condition on IO channel

SIGXCPU

Exceeded CPU time limit

SIGXFSZ

Exceeded file size limit

SIGVTALRM

Virtual time alarm

SIGPROF

Profiling time alarm

SIGWINCH

Window size changes

SIGIO

Input/output possible signal

SIGPWR

Power failure imminent.

SIGSYS

Bad system call

Implementations

impl Signal

const fn iterator() -> SignalIterator

Iterate through all signals defined by this OS

impl Signal

const fn as_str(self: Self) -> &'static str

Returns name of signal.

This function is equivalent to <Signal as AsRef<str>>::as_ref(), with difference that returned string is 'static and not bound to self's lifetime.

impl AsRef for Signal

fn as_ref(self: &Self) -> &str

impl BitOr for Signal

fn bitor(self: Self, rhs: Self) -> <Self as >::Output

impl Clone for Signal

fn clone(self: &Self) -> Signal

impl Copy for Signal

impl Debug for Signal

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for Signal

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Signal

impl Freeze for Signal

impl FromStr for Signal

fn from_str(s: &str) -> Result<Signal>

impl Hash for Signal

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for Signal

fn cmp(self: &Self, other: &Signal) -> Ordering

impl PartialEq for Signal

fn eq(self: &Self, other: &Signal) -> bool

impl PartialOrd for Signal

fn partial_cmp(self: &Self, other: &Signal) -> Option<Ordering>

impl RefUnwindSafe for Signal

impl Send for Signal

impl StructuralPartialEq for Signal

impl Sync for Signal

impl TryFrom for Signal

fn try_from(x: i32) -> Result<Self>

impl Unpin for Signal

impl UnsafeUnpin for Signal

impl UnwindSafe for Signal

impl<T> Any for Signal

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Signal

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Signal

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Signal

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Signal

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Signal

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for Signal

fn to_string(self: &Self) -> String

impl<T, U> Into for Signal

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Signal

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Signal

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>