pub struct SaFlags(/* private fields */);Expand description
Controls the behavior of a SigAction
Implementations
Sourceimpl SaFlags
impl SaFlags
Sourcepub const SA_NOCLDSTOP: Self
pub const SA_NOCLDSTOP: Self
When catching a Signal::SIGCHLD signal, the signal will be
generated only when a child process exits, not when a child process
stops.
Sourcepub const SA_NOCLDWAIT: Self
pub const SA_NOCLDWAIT: Self
When catching a Signal::SIGCHLD signal, the system will not
create zombie processes when children of the calling process exit.
Sourcepub const SA_NODEFER: Self
pub const SA_NODEFER: Self
Further occurrences of the delivered signal are not masked during the execution of the handler.
Sourcepub const SA_ONSTACK: Self
pub const SA_ONSTACK: Self
The system will deliver the signal to the process on a signal stack, specified by each thread with sigaltstack(2).
Sourcepub const SA_RESETHAND: Self
pub const SA_RESETHAND: Self
The handler is reset back to the default at the moment the signal is delivered.
Sourcepub const SA_RESTART: Self
pub const SA_RESTART: Self
Requests that certain system calls restart if interrupted by this signal. See the man page for complete details.
Sourcepub const SA_SIGINFO: Self
pub const SA_SIGINFO: Self
This flag is controlled internally by Nix.
Sourceimpl SaFlags
impl SaFlags
Sourcepub const fn bits(&self) -> c_int
pub const fn bits(&self) -> c_int
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: c_int) -> Option<Self>
pub const fn from_bits(bits: c_int) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: c_int) -> Self
pub const fn from_bits_truncate(bits: c_int) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: c_int) -> Self
pub const fn from_bits_retain(bits: c_int) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SaFlags
impl SaFlags
Sourcepub const fn iter(&self) -> Iter<SaFlags>
pub const fn iter(&self) -> Iter<SaFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SaFlags>
pub const fn iter_names(&self) -> IterNames<SaFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.