AddressFamily

Enum AddressFamily 

#[non_exhaustive]
#[repr(i32)]
pub enum AddressFamily { Unix = 1, Inet = 2, Inet6 = 10, Route = 16, Packet = 17, Ipx = 4, AppleTalk = 5, Decnet = 12, Sna = 22, Bluetooth = 31, Isdn = 34, }
These constants specify the protocol family to be used in socket and socketpair

References

address_families(7)

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unix = 1

Local communication (see unix(7))



Inet = 2

IPv4 Internet protocols (see ip(7))



Inet6 = 10

IPv6 Internet protocols (see ipv6(7))



Route = 16

Kernel interface for interacting with the routing table



Packet = 17

Low level packet interface (see packet(7))



Ipx = 4

IPX - Novell protocols



AppleTalk = 5

AppleTalk



Decnet = 12

DECet protocol sockets.



Sna = 22

IBM SNA



Bluetooth = 31

Bluetooth low-level socket protocol



Isdn = 34

New “modular ISDN” driver interface protocol

Implementations

Source

impl AddressFamily

pub const fn from_i32(family: i32) -> Option<AddressFamily>

Create a new AddressFamily from an integer value retrieved from libc, usually from the sa_family field of a sockaddr.

Currently only supports these address families: Unix, Inet (v4 & v6), Netlink, Link/Packet and System. Returns None for unsupported or unknown address families.