TcpFastOpenConnect

Struct TcpFastOpenConnect 

pub struct TcpFastOpenConnect;
Available on crate feature net only.
Enables TCP Fast Open (RFC 7413) on a connecting socket. If a fast open cookie is not available (first attempt to connect), connect syscall will behave as usual, except for internally trying to solicit a cookie from remote peer. When cookie is available, the next connect syscall will immediately succeed without actually establishing TCP connection. The connection establishment will be defered till the next write or sendmsg syscalls on the socket, allowing TCP prtocol to establish connection and send data in the same packets. Note: calling read right after connect without write on the socket will cause the blocking socket to be blocked forever.