Function fchmod
fn fchmod<Fd: std::os::fd::AsFd>(fd: Fd, mode: Mode) -> Result<()>
Change the file permission bits of the file specified by a file descriptor.
fchmodfn fchmod<Fd: std::os::fd::AsFd>(fd: Fd, mode: Mode) -> Result<()>
Change the file permission bits of the file specified by a file descriptor.