Statvfs

Struct Statvfs 

pub struct Statvfs(/* private fields */);
Wrapper around the POSIX statvfs struct

For more information see the statvfs(3) man pages.

Implementations

Source

impl Statvfs

pub fn block_size(&self) -> c_ulong

get the file system block size

pub fn fragment_size(&self) -> c_ulong

Get the fundamental file system block size

pub fn blocks(&self) -> fsblkcnt_t

Get the number of blocks.

Units are in units of fragment_size()

pub fn blocks_free(&self) -> fsblkcnt_t

Get the number of free blocks in the file system

pub fn blocks_available(&self) -> fsblkcnt_t

Get the number of free blocks for unprivileged users

pub fn files(&self) -> fsfilcnt_t

Get the total number of file inodes

pub fn files_free(&self) -> fsfilcnt_t

Get the number of free file inodes

pub fn files_available(&self) -> fsfilcnt_t

Get the number of free file inodes for unprivileged users

pub fn filesystem_id(&self) -> c_ulong

Get the file system id

pub fn flags(&self) -> FsFlags

Get the mount flags

pub fn name_max(&self) -> c_ulong

Get the maximum filename length