Enum BaudRate
enum BaudRate
Baud rates supported by the system.
For the BSDs, arbitrary baud rates can be specified by using u32s directly instead of this
enum.
B0 is special and will disable the port.
Variants
-
B0 -
B50 -
B75 -
B110 -
B134 -
B150 -
B200 -
B300 -
B600 -
B1200 -
B1800 -
B2400 -
B4800 -
B9600 -
B19200 -
B38400 -
B57600 -
B115200 -
B230400 -
B460800 -
B500000 -
B576000 -
B921600 -
B1000000 -
B1152000 -
B1500000 -
B2000000 -
B2500000 -
B3000000 -
B3500000 -
B4000000
Implementations
impl Clone for BaudRate
fn clone(self: &Self) -> BaudRate
impl Copy for BaudRate
impl Debug for BaudRate
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for BaudRate
impl Freeze for BaudRate
impl Hash for BaudRate
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for BaudRate
fn cmp(self: &Self, other: &BaudRate) -> Ordering
impl PartialEq for BaudRate
fn eq(self: &Self, other: &BaudRate) -> bool
impl PartialOrd for BaudRate
fn partial_cmp(self: &Self, other: &BaudRate) -> Option<Ordering>
impl RefUnwindSafe for BaudRate
impl Send for BaudRate
impl StructuralPartialEq for BaudRate
impl Sync for BaudRate
impl TryFrom for BaudRate
fn try_from(x: speed_t) -> Result<Self>
impl Unpin for BaudRate
impl UnsafeUnpin for BaudRate
impl UnwindSafe for BaudRate
impl<T> Any for BaudRate
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for BaudRate
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for BaudRate
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for BaudRate
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for BaudRate
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for BaudRate
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for BaudRate
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for BaudRate
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for BaudRate
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>