Enum FlowArg
enum FlowArg
Specify how transmission flow should be altered
Used as an argument to tcflow().
Variants
-
TCOOFF Suspend transmission
-
TCOON Resume transmission
-
TCIOFF Transmit a STOP character, which should disable a connected terminal device
-
TCION Transmit a START character, which should re-enable a connected terminal device
Implementations
impl Clone for FlowArg
fn clone(self: &Self) -> FlowArg
impl Copy for FlowArg
impl Debug for FlowArg
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for FlowArg
impl Freeze for FlowArg
impl Hash for FlowArg
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for FlowArg
fn cmp(self: &Self, other: &FlowArg) -> Ordering
impl PartialEq for FlowArg
fn eq(self: &Self, other: &FlowArg) -> bool
impl PartialOrd for FlowArg
fn partial_cmp(self: &Self, other: &FlowArg) -> Option<Ordering>
impl RefUnwindSafe for FlowArg
impl Send for FlowArg
impl StructuralPartialEq for FlowArg
impl Sync for FlowArg
impl Unpin for FlowArg
impl UnsafeUnpin for FlowArg
impl UnwindSafe for FlowArg
impl<T> Any for FlowArg
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FlowArg
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FlowArg
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for FlowArg
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for FlowArg
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for FlowArg
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for FlowArg
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FlowArg
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FlowArg
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>