Enum FlushArg

enum FlushArg

Specify a combination of the input and output buffers to flush

Used as an argument to tcflush().

Variants

TCIFLUSH

Flush data that was received but not read

TCOFLUSH

Flush data written but not transmitted

TCIOFLUSH

Flush both received data not read and written data not transmitted

Implementations

impl Clone for FlushArg

fn clone(self: &Self) -> FlushArg

impl Copy for FlushArg

impl Debug for FlushArg

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for FlushArg

impl Freeze for FlushArg

impl Hash for FlushArg

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl Ord for FlushArg

fn cmp(self: &Self, other: &FlushArg) -> Ordering

impl PartialEq for FlushArg

fn eq(self: &Self, other: &FlushArg) -> bool

impl PartialOrd for FlushArg

fn partial_cmp(self: &Self, other: &FlushArg) -> Option<Ordering>

impl RefUnwindSafe for FlushArg

impl Send for FlushArg

impl StructuralPartialEq for FlushArg

impl Sync for FlushArg

impl Unpin for FlushArg

impl UnsafeUnpin for FlushArg

impl UnwindSafe for FlushArg

impl<T> Any for FlushArg

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FlushArg

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FlushArg

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FlushArg

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FlushArg

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for FlushArg

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for FlushArg

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FlushArg

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FlushArg

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>