Function cfgetospeed
fn cfgetospeed(termios: &Termios) -> BaudRate
Get output baud rate (see cfgetospeed(3p)).
cfgetospeed() extracts the output baud rate from the given Termios structure.
cfgetospeedfn cfgetospeed(termios: &Termios) -> BaudRate
Get output baud rate (see cfgetospeed(3p)).
cfgetospeed() extracts the output baud rate from the given Termios structure.