Function cfsetospeed
fn cfsetospeed(termios: &mut Termios, baud: BaudRate) -> Result<()>
Set output baud rate (see cfsetospeed(3p)).
cfsetospeed() sets the output baud rate in the given Termios structure.
cfsetospeedfn cfsetospeed(termios: &mut Termios, baud: BaudRate) -> Result<()>
Set output baud rate (see cfsetospeed(3p)).
cfsetospeed() sets the output baud rate in the given Termios structure.