Struct InputFlags

struct InputFlags(_)

Flags for configuring the input mode of a terminal

Implementations

impl InputFlags

impl InputFlags

const fn empty() -> Self

Get a flags value with all bits unset.

const fn all() -> Self

Get a flags value with all known bits set.

const fn bits(self: &Self) -> tcflag_t

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

const fn from_bits(bits: tcflag_t) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

const fn from_bits_truncate(bits: tcflag_t) -> Self

Convert from a bits value, unsetting any unknown bits.

const fn from_bits_retain(bits: tcflag_t) -> Self

Convert from a bits value exactly.

fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn't correspond to any named flag.

const fn is_empty(self: &Self) -> bool

Whether all bits in this flags value are unset.

const fn is_all(self: &Self) -> bool

Whether all known bits in this flags value are set.

const fn intersects(self: &Self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

const fn contains(self: &Self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

fn insert(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

fn remove(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won't truncate other, but the ! operator will.

fn toggle(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

fn set(self: &mut Self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

const fn intersection(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

const fn union(self: Self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

const fn difference(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

const fn symmetric_difference(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

const fn complement(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl InputFlags

const fn iter(self: &Self) -> Iter<InputFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

const fn iter_names(self: &Self) -> IterNames<InputFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

impl Binary for InputFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl BitAnd for InputFlags

fn bitand(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

impl BitAndAssign for InputFlags

fn bitand_assign(self: &mut Self, other: Self)

The bitwise and (&) of the bits in two flags values.

impl BitOr for InputFlags

fn bitor(self: Self, other: InputFlags) -> Self

The bitwise or (|) of the bits in two flags values.

impl BitOrAssign for InputFlags

fn bitor_assign(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

impl BitXor for InputFlags

fn bitxor(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

impl BitXorAssign for InputFlags

fn bitxor_assign(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

impl Clone for InputFlags

fn clone(self: &Self) -> InputFlags

impl Copy for InputFlags

impl Debug for InputFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for InputFlags

impl Extend for InputFlags

fn extend<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(self: &mut Self, iterator: T)

The bitwise or (|) of the bits in each flags value.

impl Flags for InputFlags

fn bits(self: &Self) -> tcflag_t
fn from_bits_retain(bits: tcflag_t) -> InputFlags

impl Freeze for InputFlags

impl FromIterator for InputFlags

fn from_iter<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(iterator: T) -> Self

The bitwise or (|) of the bits in each flags value.

impl Hash for InputFlags

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl IntoIterator for InputFlags

fn into_iter(self: Self) -> <Self as >::IntoIter

impl LowerHex for InputFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Not for InputFlags

fn not(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl Octal for InputFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Ord for InputFlags

fn cmp(self: &Self, other: &InputFlags) -> Ordering

impl PartialEq for InputFlags

fn eq(self: &Self, other: &InputFlags) -> bool

impl PartialOrd for InputFlags

fn partial_cmp(self: &Self, other: &InputFlags) -> Option<Ordering>

impl PublicFlags for InputFlags

impl RefUnwindSafe for InputFlags

impl Send for InputFlags

impl StructuralPartialEq for InputFlags

impl Sub for InputFlags

fn sub(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl SubAssign for InputFlags

fn sub_assign(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl Sync for InputFlags

impl Unpin for InputFlags

impl UnsafeUnpin for InputFlags

impl UnwindSafe for InputFlags

impl UpperHex for InputFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for InputFlags

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for InputFlags

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for InputFlags

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for InputFlags

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for InputFlags

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for InputFlags

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for InputFlags

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for InputFlags

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for InputFlags

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>