#[repr(i32)]
#[non_exhaustive]
pub enum ClockId {
CLOCK_REALTIME,
CLOCK_MONOTONIC,
CLOCK_BOOTTIME,
CLOCK_REALTIME_ALARM,
CLOCK_BOOTTIME_ALARM,
}Expand description
The type of the clock used to mark the progress of the timer. For more details on each kind of clock, please refer to timerfd_create(2).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CLOCK_REALTIME
A settable system-wide real-time clock.
CLOCK_MONOTONIC
A non-settable monotonically increasing clock.
Does not change after system startup. Does not measure time while the system is suspended.
CLOCK_BOOTTIME
Like CLOCK_MONOTONIC, except that CLOCK_BOOTTIME includes the time
that the system was suspended.
CLOCK_REALTIME_ALARM
Like CLOCK_REALTIME, but will wake the system if it is suspended.
CLOCK_BOOTTIME_ALARM
Like CLOCK_BOOTTIME, but will wake the system if it is suspended.