Function wait
fn wait() -> Result<WaitStatus>
Wait for any child process to change status or a signal is received.
See also wait(2)
waitfn wait() -> Result<WaitStatus>
Wait for any child process to change status or a signal is received.
See also wait(2)