#[non_exhaustive]#[repr(i32)]pub enum Severity {
LOG_EMERG = 0,
LOG_ALERT = 1,
LOG_CRIT = 2,
LOG_ERR = 3,
LOG_WARNING = 4,
LOG_NOTICE = 5,
LOG_INFO = 6,
LOG_DEBUG = 7,
}Available on crate feature
syslog only.Expand description
Severity levels for log messages.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
LOG_EMERG = 0
A panic condition.
This is normally broadcast to all users.
LOG_ALERT = 1
A condition that should be corrected immediately, such as a corrupted system database.
LOG_CRIT = 2
Critical conditions, e.g., hard device errors.
LOG_ERR = 3
Errors.
LOG_WARNING = 4
Warning messages.
LOG_NOTICE = 5
Conditions that are not error conditions, but should possibly be handled specially.
LOG_INFO = 6
Informational messages.
LOG_DEBUG = 7
Messages that contain information normally of use only when debugging a program.