ClockId

Struct ClockId 

pub struct ClockId(/* private fields */);
Available on crate feature time only.
Clock identifier

Newtype pattern around libc::clockid_t.

Implementations

Source

impl ClockId

pub const CLOCK_BOOTTIME: ClockId

Available on linux_android or Emscripten or FreeBSD or Fuchsia or OpenBSD only.

Starts at zero when the kernel boots and increments monotonically in SI seconds while the machine is running.

pub const CLOCK_BOOTTIME_ALARM: ClockId

Available on linux_android or Emscripten or Fuchsia only.

Like CLOCK_BOOTTIME, but will wake the system if it is suspended..

pub const CLOCK_MONOTONIC: ClockId

Increments in SI seconds.

pub const CLOCK_MONOTONIC_COARSE: ClockId

Available on linux_android or Emscripten or FreeBSD or Fuchsia only.

Like CLOCK_MONOTONIC, but optimized for execution time at the expense of accuracy.

pub const CLOCK_MONOTONIC_RAW: ClockId

Available on linux_android or Emscripten or Fuchsia only.

Similar to CLOCK_MONOTONIC, but provides access to a raw hardware-based time that is not subject to NTP adjustments.

pub const CLOCK_PROCESS_CPUTIME_ID: ClockId

Available on apple_targets or freebsdlike or linux_android or netbsdlike or Emscripten or Fuchsia or Redox OS only.

Returns the execution time of the calling process.

pub const CLOCK_REALTIME: ClockId

Increments as a wall clock should.

pub const CLOCK_REALTIME_ALARM: ClockId

Available on linux_android or Emscripten or Fuchsia only.

Like CLOCK_REALTIME, but not settable.

pub const CLOCK_REALTIME_COARSE: ClockId

Available on linux_android or Emscripten or FreeBSD or Fuchsia only.

Like CLOCK_REALTIME, but optimized for execution time at the expense of accuracy.

pub const CLOCK_TAI: ClockId

Available on linux_android or Emscripten or Fuchsia only.

International Atomic Time.

A nonsettable system-wide clock derived from wall-clock time but ignoring leap seconds.

pub const CLOCK_THREAD_CPUTIME_ID: ClockId

Available on apple_targets or freebsdlike or linux_android or netbsdlike or Emscripten or Fuchsia only.

Returns the execution time of the calling thread.

pub const fn from_raw(clk_id: clockid_t) -> Self

Creates ClockId from raw clockid_t

pub fn pid_cpu_clock_id(pid: Pid) -> Result<Self>

Available on crate feature process only.

Returns ClockId of a pid CPU-time clock

pub fn res(self) -> Result<TimeSpec>

Available on non-Redox OS only.

Returns resolution of the clock id

pub fn now(self) -> Result<TimeSpec>

Returns the current time on the clock id

pub fn set_time(self, timespec: TimeSpec) -> Result<()>

Available on neither Hermit nor iOS nor Redox OS nor tvOS nor watchOS.

Sets time to timespec on the clock id

pub const fn as_raw(self) -> clockid_t

Gets the raw clockid_t wrapped by self