Function access
fn access<P: ?Sized + NixPath>(path: &P, amode: AccessFlags) -> Result<()>
Checks the file named by path for accessibility according to the flags given by amode
See access(2)
accessfn access<P: ?Sized + NixPath>(path: &P, amode: AccessFlags) -> Result<()>
Checks the file named by path for accessibility according to the flags given by amode
See access(2)