Function execv

fn execv<S: AsRef<std::ffi::CStr>>(path: &CStr, argv: &[S]) -> Result<Infallible>

Replace the current process image with a new one (see exec(3)).

See the ::nix::unistd::execve system call for additional details. execv performs the same action but does not allow for customization of the environment for the new process.