Function getcwd
fn getcwd() -> Result<PathBuf>
Returns the current directory as a PathBuf
Err is returned if the current user doesn't have the permission to read or search a component of the current path.
Example
use unistd;
// assume that we are allowed to get current directory
let dir = getcwd.unwrap;
println!;