Function getpgrp
fn getpgrp() -> Pid
Get the group id of the calling process (see getpgrp(3)).
Get the process group id (PGID) of the calling process. According to the man page it is always successful.
getpgrpfn getpgrp() -> Pid
Get the group id of the calling process (see getpgrp(3)).
Get the process group id (PGID) of the calling process. According to the man page it is always successful.