Function isatty
fn isatty<Fd: std::os::fd::AsFd>(fd: Fd) -> Result<bool>
Determines if the file descriptor refers to a valid terminal type device.
isattyfn isatty<Fd: std::os::fd::AsFd>(fd: Fd) -> Result<bool>
Determines if the file descriptor refers to a valid terminal type device.