Function syncfs
fn syncfs<Fd: std::os::fd::AsFd>(fd: Fd) -> Result<()>
Commit filesystem caches containing file referred to by the open file
descriptor fd to disk
See also syncfs(2)
syncfsfn syncfs<Fd: std::os::fd::AsFd>(fd: Fd) -> Result<()>
Commit filesystem caches containing file referred to by the open file
descriptor fd to disk
See also syncfs(2)