pub fn tcgetpgrp<F: AsFd>(fd: F) -> Result<Pid>Expand description
Get the terminal foreground process group (see tcgetpgrp(3)).
Get the process group id (PGID) of the foreground process group on the terminal associated to file descriptor (FD).
pub fn tcgetpgrp<F: AsFd>(fd: F) -> Result<Pid>Get the terminal foreground process group (see tcgetpgrp(3)).
Get the process group id (PGID) of the foreground process group on the terminal associated to file descriptor (FD).