Trait ErrnoSentinel

trait ErrnoSentinel: Sized

The sentinel value indicates that a function failed and more detailed information about the error can be found in errno

Required Methods

fn sentinel() -> Self

Implementors