Trait ErrnoSentinel
trait ErrnoSentinel: Sized
The sentinel value indicates that a function failed and more detailed
information about the error can be found in errno
Required Methods
fn sentinel() -> Self
Implementors
impl ErrnoSentinel for i64impl ErrnoSentinel for isizeimpl ErrnoSentinel for *mut c_voidimpl ErrnoSentinel for sighandler_timpl ErrnoSentinel for i32