Function openat2
fn openat2<P: ?Sized + NixPath, Fd: std::os::fd::AsFd>(dirfd: Fd, path: &P, how: OpenHow) -> Result<OwnedFd>
Open or create a file for reading, writing or executing.
openat2 is an extension of the openat function that allows the caller
to control how path resolution happens.