Function readlinkat

fn readlinkat<Fd: std::os::fd::AsFd, P: ?Sized + NixPath>(dirfd: Fd, path: &P) -> Result<OsString>

Read value of a symbolic link.

Equivalent to [readlink ] except for the case where path specifies a relative path, path will be interpreted relative to the path specified by dirfd. (Use AT_FDCWD to make it relative to the working directory).

See Also