Macro request_code_none
macro_rules! request_code_none {
($ty:expr, $nr:expr) => { ... };
}
Generate an ioctl request code for a command that passes no data.
This is equivalent to the _IO() macro exposed by the C ioctl API.
You should only use this macro directly if the ioctl you're working
with is "bad" and you cannot use ioctl_none!() directly.
Example
# extern crate nix;
const KVMIO: u8 = 0xAE;
ioctl_write_int_bad!;
#