Struct PollFlags

struct PollFlags(_)

These flags define the different events that can be monitored by poll and ppoll

Implementations

impl PollFlags

impl PollFlags

const fn empty() -> Self

Get a flags value with all bits unset.

const fn all() -> Self

Get a flags value with all known bits set.

const fn bits(self: &Self) -> c_short

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

const fn from_bits(bits: c_short) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

const fn from_bits_truncate(bits: c_short) -> Self

Convert from a bits value, unsetting any unknown bits.

const fn from_bits_retain(bits: c_short) -> Self

Convert from a bits value exactly.

fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn't correspond to any named flag.

const fn is_empty(self: &Self) -> bool

Whether all bits in this flags value are unset.

const fn is_all(self: &Self) -> bool

Whether all known bits in this flags value are set.

const fn intersects(self: &Self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

const fn contains(self: &Self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

fn insert(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

fn remove(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won't truncate other, but the ! operator will.

fn toggle(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

fn set(self: &mut Self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

const fn intersection(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

const fn union(self: Self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

const fn difference(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

const fn symmetric_difference(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

const fn complement(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl PollFlags

const fn iter(self: &Self) -> Iter<PollFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

const fn iter_names(self: &Self) -> IterNames<PollFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

impl Binary for PollFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl BitAnd for PollFlags

fn bitand(self: Self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

impl BitAndAssign for PollFlags

fn bitand_assign(self: &mut Self, other: Self)

The bitwise and (&) of the bits in two flags values.

impl BitOr for PollFlags

fn bitor(self: Self, other: PollFlags) -> Self

The bitwise or (|) of the bits in two flags values.

impl BitOrAssign for PollFlags

fn bitor_assign(self: &mut Self, other: Self)

The bitwise or (|) of the bits in two flags values.

impl BitXor for PollFlags

fn bitxor(self: Self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

impl BitXorAssign for PollFlags

fn bitxor_assign(self: &mut Self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

impl Clone for PollFlags

fn clone(self: &Self) -> PollFlags

impl Copy for PollFlags

impl Debug for PollFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for PollFlags

impl Extend for PollFlags

fn extend<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(self: &mut Self, iterator: T)

The bitwise or (|) of the bits in each flags value.

impl Flags for PollFlags

fn bits(self: &Self) -> c_short
fn from_bits_retain(bits: c_short) -> PollFlags

impl Freeze for PollFlags

impl FromIterator for PollFlags

fn from_iter<T: $crate::__private::core::iter::IntoIterator<Item = Self>>(iterator: T) -> Self

The bitwise or (|) of the bits in each flags value.

impl Hash for PollFlags

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl IntoIterator for PollFlags

fn into_iter(self: Self) -> <Self as >::IntoIter

impl LowerHex for PollFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Not for PollFlags

fn not(self: Self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

impl Octal for PollFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Ord for PollFlags

fn cmp(self: &Self, other: &PollFlags) -> Ordering

impl PartialEq for PollFlags

fn eq(self: &Self, other: &PollFlags) -> bool

impl PartialOrd for PollFlags

fn partial_cmp(self: &Self, other: &PollFlags) -> Option<Ordering>

impl PublicFlags for PollFlags

impl RefUnwindSafe for PollFlags

impl Send for PollFlags

impl StructuralPartialEq for PollFlags

impl Sub for PollFlags

fn sub(self: Self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl SubAssign for PollFlags

fn sub_assign(self: &mut Self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won't truncate other, but the ! operator will.

impl Sync for PollFlags

impl Unpin for PollFlags

impl UnsafeUnpin for PollFlags

impl UnwindSafe for PollFlags

impl UpperHex for PollFlags

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for PollFlags

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PollFlags

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PollFlags

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for PollFlags

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for PollFlags

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for PollFlags

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for PollFlags

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PollFlags

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PollFlags

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>