Enum ForkptyResult
enum ForkptyResult
A successful result of [forkpty()].
Variants
-
Parent { child: crate::unistd::Pid, master: OwnedFd } This is the parent process of the underlying fork.
-
Child This is the child process of the underlying fork.
Implementations
impl Debug for ForkptyResult
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for ForkptyResult
impl RefUnwindSafe for ForkptyResult
impl Send for ForkptyResult
impl Sync for ForkptyResult
impl Unpin for ForkptyResult
impl UnsafeUnpin for ForkptyResult
impl UnwindSafe for ForkptyResult
impl<T> Any for ForkptyResult
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ForkptyResult
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ForkptyResult
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ForkptyResult
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for ForkptyResult
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ForkptyResult
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ForkptyResult
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>