Function memfd_create

fn memfd_create<P: NixPath + ?Sized>(name: &P, flags: MFdFlags) -> Result<OwnedFd>

Creates an anonymous file that lives in memory, and return a file-descriptor to it.

The file behaves like a regular file, and so can be modified, truncated, memory-mapped, and so on. However, unlike a regular file, it lives in RAM and has a volatile backing storage.

For more information, see memfd_create(2).