Function sigaction

unsafe fn sigaction(signal: Signal, sigaction: &SigAction) -> Result<SigAction>

Changes the action taken by a process on receipt of a specific signal.

signal can be any signal except SIGKILL or SIGSTOP. On success, it returns the previous action for the given signal. If sigaction fails, no new signal handler is installed.

Safety