Struct SigAction
struct SigAction { ... }
Action to take on receipt of a signal. Corresponds to sigaction.
Implementations
impl SigAction
fn new(handler: SigHandler, flags: SaFlags, mask: SigSet) -> SigActionCreates a new action.
The
SA_SIGINFObit in theflagsargument is ignored (it will be set only ifhandleris theSigActionvariant).maskspecifies other signals to block during execution of the signal-catching function.fn flags(self: &Self) -> SaFlagsReturns the flags set on the action.
fn mask(self: &Self) -> SigSetReturns the set of signals that are blocked during execution of the action's signal-catching function.
fn handler(self: &Self) -> SigHandlerReturns the action's handler.
impl Clone for SigAction
fn clone(self: &Self) -> SigAction
impl Copy for SigAction
impl Debug for SigAction
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for SigAction
impl Freeze for SigAction
impl Hash for SigAction
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl PartialEq for SigAction
fn eq(self: &Self, other: &SigAction) -> bool
impl RefUnwindSafe for SigAction
impl Send for SigAction
impl StructuralPartialEq for SigAction
impl Sync for SigAction
impl Unpin for SigAction
impl UnsafeUnpin for SigAction
impl UnwindSafe for SigAction
impl<T> Any for SigAction
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SigAction
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SigAction
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for SigAction
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for SigAction
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for SigAction
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for SigAction
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SigAction
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SigAction
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>