Function lutimes
fn lutimes<P: ?Sized + NixPath>(path: &P, atime: &TimeVal, mtime: &TimeVal) -> Result<()>
Change the access and modification times of a file without following symlinks.
lutimes(path, times) is identical to
utimensat(None, path, times, UtimensatFlags::NoFollowSymlink). The former
is a deprecated API so prefer using the latter if the platforms you care
about support it.