Function mkdirat
fn mkdirat<Fd: std::os::fd::AsFd, P: ?Sized + NixPath>(dirfd: Fd, path: &P, mode: Mode) -> Result<()>
Create a directory at the path specified by dirfd and path.
If path is a relative path, then it is interpreted relative to the directory
referred to by the file descriptor dirfd. (One can use AT_FDCWD to
specify the current working directory in dirfd). If path is absolute,
then dirfd is ignored.