Function utimes
fn utimes<P: ?Sized + NixPath>(path: &P, atime: &TimeVal, mtime: &TimeVal) -> Result<()>
Change the access and modification times of a file.
utimes(path, times) is identical to
utimensat(None, path, times, UtimensatFlags::FollowSymlink). The former
is a deprecated API so prefer using the latter if the platforms you care
about support it.