pub struct FsType(pub __fsword_t);Available on crate feature
fs and (Android, or Cygwin, or FreeBSD, or Linux and musl, or Linux and neither musl nor s390x, or Linux and OpenHarmony, or Linux and s390x) only.Expand description
Describes the file system type as known by the operating system.
Tuple Fields
0: __fsword_tTrait Implementations
impl Copy for FsType
impl Eq for FsType
impl StructuralPartialEq for FsType