Struct FsType
struct FsType(2838)
Describes the file system type as known by the operating system.
Implementations
impl Clone for FsType
fn clone(self: &Self) -> FsType
impl Copy for FsType
impl Debug for FsType
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for FsType
impl Freeze for FsType
impl PartialEq for FsType
fn eq(self: &Self, other: &FsType) -> bool
impl RefUnwindSafe for FsType
impl Send for FsType
impl StructuralPartialEq for FsType
impl Sync for FsType
impl Unpin for FsType
impl UnsafeUnpin for FsType
impl UnwindSafe for FsType
impl<T> Any for FsType
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FsType
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FsType
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for FsType
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for FsType
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for FsType
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for FsType
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FsType
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FsType
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>