Struct Statvfs
struct Statvfs(_)
Wrapper around the POSIX statvfs struct
For more information see the statvfs(3) man pages.
Implementations
impl Statvfs
fn block_size(self: &Self) -> c_ulongget the file system block size
fn fragment_size(self: &Self) -> c_ulongGet the fundamental file system block size
fn blocks(self: &Self) -> fsblkcnt_tGet the number of blocks.
Units are in units of
fragment_size()fn blocks_free(self: &Self) -> fsblkcnt_tGet the number of free blocks in the file system
fn blocks_available(self: &Self) -> fsblkcnt_tGet the number of free blocks for unprivileged users
fn files(self: &Self) -> fsfilcnt_tGet the total number of file inodes
fn files_free(self: &Self) -> fsfilcnt_tGet the number of free file inodes
fn files_available(self: &Self) -> fsfilcnt_tGet the number of free file inodes for unprivileged users
fn filesystem_id(self: &Self) -> c_ulongGet the file system id
fn flags(self: &Self) -> FsFlagsGet the mount flags
fn name_max(self: &Self) -> c_ulongGet the maximum filename length
impl Clone for Statvfs
fn clone(self: &Self) -> Statvfs
impl Copy for Statvfs
impl Debug for Statvfs
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Statvfs
impl Freeze for Statvfs
impl Hash for Statvfs
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl PartialEq for Statvfs
fn eq(self: &Self, other: &Statvfs) -> bool
impl RefUnwindSafe for Statvfs
impl Send for Statvfs
impl StructuralPartialEq for Statvfs
impl Sync for Statvfs
impl Unpin for Statvfs
impl UnsafeUnpin for Statvfs
impl UnwindSafe for Statvfs
impl<T> Any for Statvfs
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Statvfs
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Statvfs
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Statvfs
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Statvfs
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Statvfs
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Statvfs
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Statvfs
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Statvfs
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>