Enum SetArg
enum SetArg
Specify when a port configuration change should occur.
Used as an argument to tcsetattr()
Variants
-
TCSANOW The change will occur immediately
-
TCSADRAIN The change occurs after all output has been written
-
TCSAFLUSH Same as
TCSADRAIN, but will also flush the input buffer
Implementations
impl Clone for SetArg
fn clone(self: &Self) -> SetArg
impl Copy for SetArg
impl Debug for SetArg
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for SetArg
impl Freeze for SetArg
impl Hash for SetArg
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl Ord for SetArg
fn cmp(self: &Self, other: &SetArg) -> Ordering
impl PartialEq for SetArg
fn eq(self: &Self, other: &SetArg) -> bool
impl PartialOrd for SetArg
fn partial_cmp(self: &Self, other: &SetArg) -> Option<Ordering>
impl RefUnwindSafe for SetArg
impl Send for SetArg
impl StructuralPartialEq for SetArg
impl Sync for SetArg
impl Unpin for SetArg
impl UnsafeUnpin for SetArg
impl UnwindSafe for SetArg
impl<T> Any for SetArg
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SetArg
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SetArg
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for SetArg
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for SetArg
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for SetArg
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for SetArg
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SetArg
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SetArg
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>