pub struct Termios {
pub input_flags: InputFlags,
pub output_flags: OutputFlags,
pub control_flags: ControlFlags,
pub local_flags: LocalFlags,
pub control_chars: [cc_t; 32],
pub line_discipline: cc_t,
/* private fields */
}Available on crate feature
term only.Expand description
Stores settings for the termios API
This is a wrapper around the libc::termios struct that provides a safe interface for the
standard fields. The only safe way to obtain an instance of this struct is to extract it from
an open port using tcgetattr().
Fields
input_flags: InputFlagsInput mode flags (see termios.c_iflag documentation)
output_flags: OutputFlagsOutput mode flags (see termios.c_oflag documentation)
control_flags: ControlFlagsControl mode flags (see termios.c_cflag documentation)
local_flags: LocalFlagsLocal mode flags (see termios.c_lflag documentation)
control_chars: [cc_t; 32]Control characters (see termios.c_cc documentation)
line_discipline: cc_tAvailable on
linux_android only.Line discipline (see termios.c_line documentation)