Enum Id
enum Id<'fd>
The ID argument for waitid
Variants
-
All Wait for any child
-
Pid(crate::unistd::Pid) Wait for the child whose process ID matches the given PID
-
PGid(crate::unistd::Pid) Wait for the child whose process group ID matches the given PID
If the PID is zero, the caller's process group is used since Linux 5.4.
-
PIDFd(std::os::unix::io::BorrowedFd<'fd>) Wait for the child referred to by the given PID file descriptor
Implementations
impl<'fd> Debug for Id<'fd>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'fd> Freeze for Id<'fd>
impl<'fd> RefUnwindSafe for Id<'fd>
impl<'fd> Send for Id<'fd>
impl<'fd> Sync for Id<'fd>
impl<'fd> Unpin for Id<'fd>
impl<'fd> UnsafeUnpin for Id<'fd>
impl<'fd> UnwindSafe for Id<'fd>
impl<T> Any for Id<'fd>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Id<'fd>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Id<'fd>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Id<'fd>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Id<'fd>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Id<'fd>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Id<'fd>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>