Enum Whence

enum Whence

Directive that tells lseek and lseek64 what the offset is relative to.

Variants

SeekSet

Specify an offset relative to the start of the file.

SeekCur

Specify an offset relative to the current file location.

SeekEnd

Specify an offset relative to the end of the file.

SeekData

Specify an offset relative to the next location in the file greater than or equal to offset that contains some data. If offset points to some data, then the file offset is set to offset.

SeekHole

Specify an offset relative to the next hole in the file greater than or equal to offset. If offset points into the middle of a hole, then the file offset should be set to offset. If there is no hole past offset, then the file offset should be adjusted to the end of the file (i.e., there is an implicit hole at the end of any file).

Implementations

impl Clone for Whence

fn clone(self: &Self) -> Whence

impl Copy for Whence

impl Debug for Whence

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Whence

impl RefUnwindSafe for Whence

impl Send for Whence

impl Sync for Whence

impl Unpin for Whence

impl UnsafeUnpin for Whence

impl UnwindSafe for Whence

impl<T> Any for Whence

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Whence

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Whence

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Whence

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Whence

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Whence

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Whence

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Whence

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Whence

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>