Function eaccess

fn eaccess<P: ?Sized + NixPath>(path: &P, mode: AccessFlags) -> Result<()>

Checks the file named by path for accessibility according to the flags given by mode using effective UID, effective GID and supplementary group lists.

References