Function execvpe

fn execvpe<SA: AsRef<std::ffi::CStr>, SE: AsRef<std::ffi::CStr>>(filename: &CStr, args: &[SA], env: &[SE]) -> Result<Infallible>

Replace the current process image with a new one and replicate shell PATH searching behavior (see execvpe(3)).

This functions like a combination of execvp(2) and execve(2) to pass an environment and have a search path. See these two for additional information.