Function pipe2

fn pipe2(flags: OFlag) -> Result<(OwnedFd, OwnedFd)>

Like pipe, but allows setting certain file descriptor flags.

The following flags are supported, and will be set atomically as the pipe is created:

See also pipe(2)