Function unlinkat

fn unlinkat<Fd: std::os::fd::AsFd, P: ?Sized + NixPath>(dirfd: Fd, path: &P, flag: UnlinkatFlags) -> Result<()>

Remove a directory entry

In the case of a relative path, the directory entry to be removed is determined relative to the directory associated with the file descriptor dirfd (Use AT_FDCWD if you want to specify the current working directory in dirfd). In the case of an absolute path, dirfd is ignored.

If flag is UnlinkatFlags::RemoveDir then removal of the directory entry specified by dirfd and path is performed.

References

See also unlinkat(2)